@@ -221,7 +221,14 @@ impl<L: Language> Matcher<L> for Pattern<L> {
     node: Node<'tree, D>,
     env: &mut Cow<MetaVarEnv<'tree, D>>,
   ) -> Option<Node<'tree, D>> {
-    match_node_non_recursive(self, node, env)
+    // do not pollute the env if pattern does not match
+    let mut may_write = Cow::Borrowed(env.as_ref());
+    let node = match_node_non_recursive(self, node, &mut may_write)?;
+    if let Cow::Owned(map) = may_write {
+      // only change env when pattern matches
+      *env = Cow::Owned(map);
+    }
+    Some(node)
   }
 
   fn potential_kinds(&self) -> Option<bit_set::BitSet> {
@@ -312,6 +319,20 @@ mod test {
     assert_eq!(env["VALUE"], "123");
   }
 
+  #[test]
+  fn test_pattern_should_not_pollute_env() {
+    // gh issue #1164
+    let pattern = Pattern::str("const $A = 114", Tsx);
+    let cand = pattern_node("const a = 514");
+    let cand = cand.root().child(0).unwrap();
+    let map = MetaVarEnv::new();
+    let mut env = Cow::Borrowed(&map);
+    let nm = pattern.match_node_with_env(cand, &mut env);
+    assert!(nm.is_none());
+    assert!(env.get_match("A").is_none());
+    assert!(map.get_match("A").is_none());
+  }
+
   #[test]
   fn test_match_non_atomic() {
     let env = match_env("const a = $VALUE", "const a = 5 + 3");
