@@ -15,6 +15,9 @@ assert node2 is not None
 
 def test_one_fix():
     edit = node1.replace("let b = 456")
+    r = node1.range()
+    assert edit.position == r.start.index
+    assert edit.deleted_length == r.end.index - edit.position
     s = node1.commit_edits([edit])
     assert s == "let b = 456"
     s = root.commit_edits([edit])
@@ -27,4 +30,12 @@ def test_multiple_fix():
     edits = [node.replace('114514') for node in nodes]
     edits = sorted(edits, key=lambda x: x.position, reverse=True)
     s = root.commit_edits(edits)
-    assert s == "いいよ = log(114514) + log(114514)"
\ No newline at end of file
+    assert s == "いいよ = log(114514) + log(114514)"
+
+def test_change_unicode():
+    sg = SgRoot('いいよ = log(こいよ)', "javascript")
+    root = sg.root()
+    nodes = root.find_all(kind="identifier")
+    edits = [node.replace('114514') for node in nodes]
+    s = root.commit_edits(edits)
+    assert s == "114514 = 114514(114514)"
\ No newline at end of file
